==========
AUTHORS
==========

Finchan is written and maintained by qytz and
various contributors:

Development Lead
----------------

* qytz <hhhhhf@foxmail.com>

Patches and Suggestions
-----------------------

None yet. Why not be the first?
